OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Contraseña incorrecta",
    "The new password can not be the same as the previous one" : "La nueva contraseña no puede ser la misma que la contraseña anterior",
    "No user supplied" : "No se especificó un usuario",
    "Authentication error" : "Error de autenticación",
    "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación de administrador incorrecta. Por favor compruebe la contraseña e inténtelo de nuevo.",
    "Unable to change password" : "No se ha podido cambiar la contraseña",
    "Couldn't send reset email. Please contact your administrator." : "No se pudo enviar correo de restauración de contraseña. Por favor contacta a tu administrador.",
    "Migration Completed" : "Migración Completada",
    "Group already exists." : "Este grupo ya existe.",
    "Unable to add group." : "No se pudo agregar el grupo.",
    "Unable to delete group." : "No se pudo eliminar el grupo.",
    "Saved" : "Guardado",
    "test email settings" : "probar configuración de correo",
    "Email sent" : "Correo electrónico enviado",
    "You need to set your user email before being able to send test emails." : "Necesitas establecer tu correo de usuario antes de poder enviar correos de prueba.",
    "Invalid mail address" : "Dirección de correo electrónico inválido.",
    "A user with that name already exists." : "Ya existe un usuario con ese nombre.",
    "Unable to create user." : "No se pudo crear usuario.",
    "Unable to delete user." : "No se pudo eliminar usuario.",
    "Forbidden" : "Prohibido",
    "Invalid user" : "Usuario inválido",
    "Unable to change mail address" : "No se pudo cambiar la dirección de correo electrónico",
    "Your full name has been changed." : "Se ha cambiado su nombre completo.",
    "Unable to change full name" : "No se puede cambiar el nombre completo",
    "__language_name__" : "Español (México)",
    "Language changed" : "Idioma cambiado",
    "Invalid request" : "Petición no válida",
    "Admins can't remove themself from the admin group" : "Los administradores no se pueden eliminar a ellos mismos del grupo de administrador",
    "Couldn't remove app." : "No se pudo quitar la aplicación.",
    "Official" : "Oficial",
    "Approved" : "Aprobados",
    "All" : "Todos",
    "Enabled" : "Habilitado",
    "Not enabled" : "Deshabilitado",
    "No apps found for your version" : "No se encontraron aplicaciones en su versión.",
    "The app will be downloaded from the app store" : "La aplicación será descargada de la tienda de aplicaciones",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Las aplicaciones oficiales son desarrolladas por y dentro de la comunidad ownCloud. Ofrecen funciones centrales a ownCloud y están listo para uso masivo.",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Las aplicaciones aprobadas son desarrolladas por desarrolladores confiables y han pasado una revisión obligatoria de seguridad. Se les da mantenimiento activamente en un repositorio de código abierto y sus administradores consideran estas aplicaciones como estables para uso casual a normal.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Esta aplicación no ha sido revisada en busca de problemas de seguridad y es nueva o se conoce que es inestable. Instálela bajo su propio riesgo.",
    "Please wait...." : "Espere, por favor....",
    "Error while disabling app" : "Error mientras se desactivaba la aplicación",
    "Disable" : "Deshabilitar",
    "Enable" : "Habilitar",
    "Error while enabling app" : "Error mientras se activaba la aplicación",
    "Updating...." : "Actualizando....",
    "Error while updating app" : "Error mientras se actualizaba la aplicación",
    "Updated" : "Actualizado",
    "Uninstalling ...." : "Desinstalando...",
    "Error while uninstalling app" : "Error al desinstalar aplicación",
    "Uninstall" : "Desinstalar",
    "Experimental" : "Experimental",
    "Add trusted domain" : "Agregar dominio de confianza",
    "Migration in progress. Please wait until the migration is finished" : "Migración en proceso. Por favor espere hasta que la migración haya terminado.",
    "Migration started …" : "Migración iniciada...",
    "Delete" : "Eliminar",
    "Disconnect" : "Desconectar",
    "Sending..." : "Enviando...",
    "Select a profile picture" : "Seleccionar una imagen de perfil",
    "Groups" : "Grupos",
    "undo" : "deshacer",
    "never" : "nunca",
    "add group" : "añadir Grupo",
    "enabled" : "activado",
    "disabled" : "desactivado",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Cambiar la contraseña resultará en la pérdida de datos, porque la recuperación de datos no está disponible para este usuario",
    "A valid username must be provided" : "Se debe proporcionar un nombre de usuario válido",
    "A valid password must be provided" : "Se debe proporcionar una contraseña válida",
    "Cheers!" : "¡Saludos!",
    "Forum" : "Foro",
    "Cron" : "Cron",
    "Open documentation" : "Abrir documentación",
    "Execute one task with each page loaded" : "Ejecutar una tarea con cada página cargada",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php se registra en un servicio webcron para llamar a cron.php cada 15 minutos a través de HTTP.",
    "Server-side encryption" : "Encriptación del lado del servidor",
    "Be aware that encryption always increases the file size." : "Toma en cuenta que el cifrado siempre aumenta el tamaño de archivo.",
    "This is the final warning: Do you really want to enable encryption?" : "Ésta es el último aviso: ¿Realmente quieres habilitar el cifrado de archivos?",
    "Enable encryption" : "Habilitar cifrado",
    "Sharing" : "Compartiendo",
    "Allow apps to use the Share API" : "Permitir a las aplicaciones utilizar la API para Compartir",
    "Allow users to share via link" : "Permitir a los usuarios compatir mediante vínculos",
    "Allow public uploads" : "Permitir subidas públicas",
    "Enforce password protection" : "Forzar la protección mediante contraseña",
    "Set default expiration date" : "Establecer un periodo de expiración por defecto",
    "Allow users to send mail notification for shared files" : "Permitir a los usuarios mandar notificaciones por correo para archivos compartidos",
    "Allow users to share file via social media" : "Permitir a los usuarios compartir archivos vía redes sociales",
    "Expire after " : "Expirar después de ",
    "days" : "días",
    "Enforce expiration date" : "Forzar uso de este periodo de expiración",
    "Allow resharing" : "Permitir a usuarios compartir contenido de otros usuarios",
    "Allow sharing with groups" : "Permitir compartir con grupos",
    "Restrict users to only share with users in their groups" : "Restringir a usuarios para que solo puedan compartir con usuarios dentro de sus grupos",
    "Allow users to send mail notification for shared files to other users" : "Permitir a usuarios mandar notificaciones por correo para archivos compartidos por otros usuarios",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Todo (Información, Avisos, Errores, debug y problemas fatales)",
    "Info, warnings, errors and fatal issues" : "Información, Avisos, Errores y problemas fatales",
    "Warnings, errors and fatal issues" : "Advertencias, errores y problemas fatales",
    "Errors and fatal issues" : "Errores y problemas fatales",
    "Fatal issues only" : "Problemas fatales solamente",
    "Log" : "Registro",
    "What to log" : "¿Qué cosas registrar?",
    "Download logfile (%s)" : "Descargar archivo de registro (%s)",
    "None" : "Ninguno",
    "Login" : "Iniciar sesión",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Servidor de correo electrónico",
    "Encryption" : "Cifrado",
    "Authentication method" : "Método de autenticación",
    "Authentication required" : "Se necesita autenticación",
    "Server address" : "Dirección del servidor",
    "Port" : "Puerto",
    "Credentials" : "Credenciales",
    "SMTP Username" : "Nombre de usuario SMTP",
    "SMTP Password" : "Contraseña SMTP",
    "Store credentials" : "Almacenar credenciales",
    "Test email settings" : "Probar configuración de correo electrónico",
    "Send email" : "Enviar correo",
    "Security & setup warnings" : "Seguridad & alertas de configuración",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "No se ha encontrado el modulo PHP 'fileinfo'. Le recomendamos encarecidamente que habilite este módulo para obtener mejores resultados con la detección de tipos MIME.",
    "System locale can not be set to a one which supports UTF-8." : "No se puede escoger una configuración regional que soporte UTF-8.",
    "This means that there might be problems with certain characters in file names." : "Esto significa que puede haber problemas con ciertos caracteres en los nombres de los archivos.",
    "Get the apps to sync your files" : "Obtener las aplicaciones para sincronizar sus archivos",
    "Desktop client" : "Cliente de escritorio",
    "Show First Run Wizard again" : "Mostrar nuevamente el Asistente de ejecución inicial",
    "Profile picture" : "Foto de perfil",
    "Upload new" : "Subir otra",
    "Remove image" : "Borrar imagen",
    "Cancel" : "Cancelar",
    "Email" : "Correo electrónico",
    "Your email address" : "Su dirección de correo",
    "Password" : "Contraseña",
    "Unable to change your password" : "No se ha podido cambiar su contraseña",
    "Current password" : "Contraseña actual",
    "New password" : "Nueva contraseña",
    "Change password" : "Cambiar contraseña",
    "Language" : "Idioma",
    "Help translate" : "Ayúdanos a traducir",
    "Unlimited" : "Ilimitado",
    "Sessions" : "Sesiones",
    "App passwords" : "Contraseñas de aplicaciones",
    "Name" : "Nombre",
    "Username" : "Nombre de usuario",
    "Version" : "Versión",
    "Personal" : "Personal",
    "Admin" : "Administración",
    "Error" : "Error",
    "E-Mail" : "Correo electrónico",
    "Create" : "Crear",
    "Admin Recovery Password" : "Recuperación de la contraseña de administración",
    "Enter the recovery password in order to recover the users files during password change" : "Introduzca la contraseña de recuperación a fin de recuperar los archivos de los usuarios durante el cambio de contraseña.",
    "Group" : "Grupo",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Por favor indique la cúota de almacenamiento (ej: \"512 MB\" o \"12 GB\")",
    "Other" : "Otro",
    "Full Name" : "Nombre completo",
    "change full name" : "cambiar el nombre completo",
    "set new password" : "establecer nueva contraseña",
    "Default" : "Predeterminado",
    "Share" : "Compartir",
    "Domain" : "Dominio",
    "Add" : "Agregar"
},
"nplurals=2; plural=(n != 1);");
